#define _GENERAL_H
extern "C"{
#include "cs.h"
}
#include <math.h>
#include <map>                  
#include <stdlib.h>    
#include <new>            
#include "R.h" 
#include "Rmath.h" 
#include <iostream>
#include <limits>
using namespace std;
